@@ -87,7 +87,7 @@ static void SexpObject_clear(SexpObject *sexpobj)
 static void SexpObject_CObject_destroy(PyObject *rpycapsule)
 {
   SexpObject *sexpobj_ptr = (SexpObject *)(PyCapsule_GetPointer(rpycapsule,
-								"rpy2.rinterface._C_API_"));
+								"rpy2.rinterface._rinterface.SEXPOBJ_C_API"));
   SexpObject_clear(sexpobj_ptr);
 }
 
@@ -126,7 +126,7 @@ static SexpObject* Rpy_PreserveObject(SEXP object) {
     sexpobj_ptr->pycount = 1;
     sexpobj_ptr->sexp = object;
     capsule = PyCapsule_New((void *)(sexpobj_ptr),
-			    "rpy2.rinterface._C_API_",
+			    "rpy2.rinterface._rinterface.SEXPOBJ_C_API",
 			    SexpObject_CObject_destroy);
     if (PyDict_SetItem(Rpy_R_Precious, key, capsule) == -1) {
       Py_DECREF(key);
@@ -156,7 +156,7 @@ static SexpObject* Rpy_PreserveObject(SEXP object) {
   } else {
     /* Reminder: capsule is a borrowed reference */
     sexpobj_ptr = (SexpObject *)(PyCapsule_GetPointer(capsule,
-						      "rpy2.rinterface._C_API_"));
+						      "rpy2.rinterface._rinterface.SEXPOBJ_C_API"));
     if (sexpobj_ptr != NULL) {
       sexpobj_ptr->pycount++;
     }
@@ -198,8 +198,13 @@ static int Rpy_ReleaseObject(SEXP object) {
   PyObject *capsule = PyDict_GetItem(Rpy_R_Precious, key);
   /* capsule is a borrowed reference */
   if (capsule == NULL) {
+    /* FIXME: should all rpy2 proxy objects have an associated capsule ?
+     *        If yes, why are we here ?
+     */
+    printf("Warning: the rpy2 object we are trying to release has no associated capsule.\n");
     if (reset_error_state) {
       PyErr_Restore(ptype, pvalue, ptraceback);
+      printf("Restoring an earlier exception.\n");
       printf("Error:Trying to release object ID %ld while not preserved\n",
 	     PyLong_AsLong(key));
     } else {
@@ -212,7 +217,7 @@ static int Rpy_ReleaseObject(SEXP object) {
   } 
 
   SexpObject *sexpobj_ptr = (SexpObject *)(PyCapsule_GetPointer(capsule,
-								"rpy2.rinterface._C_API_"));
+								"rpy2.rinterface._rinterface.SEXPOBJ_C_API"));
   if (sexpobj_ptr == NULL) {
     if (reset_error_state) {
       if (PyErr_Occurred()) {
@@ -318,9 +323,12 @@ static int Rpy_ReleaseObject(SEXP object) {
   /* } */
 
 PyDoc_STRVAR(Rpy_ProtectedIDs_doc,
-             "Return a tuple with the R IDs for the objects protected\
- from R's garbage collection by rpy2, along with the number of rpy2 objects\
- protecting them from collection.\n");
+             "Return a tuple of pairs with each: \n"
+	     "- an R ID for the objects protected from R's garbage collection by rpy2\n"
+	     "- the number of rpy2 objects protecting that R object from collection.\n\n"
+	     "The R ID is a memory pointer for the R-defined C-structure "
+	     "containing all information about the R object. It is available "
+	     "from an rpy2 object through the read-only attribute `rid`.");
 /* Return a tuple with IDs of R objects protected by rpy2 and counts */
 static PyObject* Rpy_ProtectedIDs(PyObject *self) {
   PyObject *key, *capsule;
@@ -335,7 +343,7 @@ static PyObject* Rpy_ProtectedIDs(PyObject *self) {
     Py_INCREF(key);
     PyTuple_SET_ITEM(id_count, 0, key);
     sexpobject_ptr = (SexpObject *)(PyCapsule_GetPointer(capsule,
-							 "rpy2.rinterface._C_API_"));
+							 "rpy2.rinterface._rinterface.SEXPOBJ_C_API"));
     PyTuple_SET_ITEM(id_count, 1, PyLong_FromLong(sexpobject_ptr->pycount));
     PyTuple_SET_ITEM(ids, pos_ids, id_count);
     pos_ids++;
