@@ -7,6 +7,9 @@ rinterface.initr()
 
 if sys.version_info[0] == 3:
     long = int
+    is_py3 = True
+else:
+    is_py3 = False
 
 class SexpClosureTestCase(unittest.TestCase):
 
@@ -34,6 +37,18 @@ class SexpClosureTestCase(unittest.TestCase):
         
         self.assertRaises(rinterface.RRuntimeError, sum, letters)
 
+    @unittest.skipUnless(is_py3,
+                         "Unicode-named arguments for R functions are only available with Python 3")
+    def testUTF8params(self):
+        c = rinterface.globalenv.get('c')
+        d = dict([(u'哈哈', 1)])
+        res = c(**d)
+        self.assertEqual(u'哈哈', res.do_slot("names")[0])
+
+    def testEmptystringparams(self):
+        d = dict([('', 1)])
+        self.assertRaises(TypeError, rinterface.baseenv['list'], **d)
+
     def testClosureenv(self):
         exp = rinterface.parse("function(x) { x[y] }")
         fun = rinterface.baseenv["eval"](exp)
