@@ -46,15 +46,23 @@ and provide a more dynamic mapping.
 import rpy2.robjects as robjects
 import rpy2.robjects.conversion as conversion
 import rpy2.rinterface as rinterface
-from rpy2.robjects.packages import importr
+from rpy2.robjects.packages import importr, WeakPackage
 import copy
 import warnings
 
 NULL = robjects.NULL
 
-ggplot2 = importr('ggplot2')
+ggplot2 = importr('ggplot2', on_conflict="warn")
+ggplot2 = WeakPackage(ggplot2._env,
+                      ggplot2.__rname__,
+                      translation=ggplot2._translation,
+                      exported_names=ggplot2._exported_names,
+                      on_conflict="warn",
+                      version=ggplot2.__version__,
+                      symbol_r2python=ggplot2._symbol_r2python,
+                      symbol_check_after=ggplot2._symbol_check_after)
 
-TARGET_VERSION = '1.0.1'
+TARGET_VERSION = '2.1.0'
 if ggplot2.__version__ != TARGET_VERSION:
    warnings.warn('This was designed againt ggplot2 version %s but you have %s' % (TARGET_VERSION, ggplot2.__version__))
 ggplot2_env = robjects.baseenv['as.environment']('package:ggplot2')
@@ -136,10 +144,7 @@ class AesString(robjects.Vector):
     @classmethod
     def new(cls, **kwargs):
        """Constructor for the class AesString."""
-       new_kwargs = copy.copy(kwargs)
-       for k,v in kwargs.items():
-          new_kwargs[k] = as_symbol(v)
-       res = cls(cls._constructor(**new_kwargs))
+       res = cls(cls._constructor(**kwargs))
        return res
 aes_string = AesString.new
 
@@ -181,10 +186,6 @@ class Stat(GBaseObject):
     Stat* (e.g., StatAbline, StatBin, etc...). """
     pass
 
-class StatAbline(Stat):
-    """ Line from slope and intercept. """
-    _constructor = ggplot2_env['stat_abline']
-stat_abline = StatAbline.new
 
 class StatBin(Stat):
     """ Bin data. """
@@ -193,14 +194,24 @@ stat_bin = StatBin.new
 
 class StatBin2D(Stat):
     """ 2D binning of data into squares/rectangles. """
-    _constructor = ggplot2_env['stat_bin2d']
+    try:
+       _constructor = ggplot2_env['stat_bin_2d']
+    except:
+       # fallback for versions of ggplot2 < 2.0
+       _constructor = ggplot2_env['stat_bin2d']
 stat_bin2d = StatBin2D.new
+stat_bin_2d=StatBin2D.new
 
 class StatBinhex(Stat):
     """ 2D binning of data into hexagons. """
-    _constructor = ggplot2_env['stat_binhex']
+    try:
+       _constructor = ggplot2_env['stat_bin_hex']
+    except:
+       # fallback for versions of ggplot2 < 2.0
+       _constructor = ggplot2_env['stat_binhex']
 stat_binhex = StatBinhex.new
-   
+stat_bin_hex=StatBinhex.new
+
 class StatBoxplot(Stat):
     """ Components of box and whisker plot. """
     _constructor = ggplot2_env['stat_boxplot']
@@ -218,19 +229,18 @@ stat_density = StatDensity.new
 
 class StatDensity2D(Stat):
     """ 2D density estimate """
-    _constructor = ggplot2_env['stat_density2d']
+    try:
+       _constructor = ggplot2_env['stat_density_2d']
+    except:
+       _constructor = ggplot2_env['stat_density2d']
 stat_density2d = StatDensity2D.new
+stat_density_2d=StatDensity2D.new
 
 class StatFunction(Stat):
     """ Superimpose a function """
     _constructor = ggplot2_env['stat_function']
 stat_function = StatFunction.new
 
-class StatHline(Stat):
-    """ Horizontal line """
-    _constructor = ggplot2_env['stat_hline']
-stat_hline = StatHline.new
-
 class StatIdentity(Stat):
     """ Identity function """
     _constructor = ggplot2_env['stat_identity']
@@ -267,16 +277,20 @@ class StatSummary(Stat):
     _constructor = ggplot2_env['stat_summary']
 stat_summary = StatSummary.new
 
+class StatSummary2D(Stat):
+    """ Summarize values for y at every unique value for x"""
+    try:
+       _constructor = ggplot2_env['stat_summary_2d']
+    except:
+       _constructor = ggplot2_env['stat_summary2d']
+stat_summary2d = StatSummary2D.new
+stat_summary_2d = StatSummary2D.new
+
 class StatUnique(Stat):
     """ Remove duplicates. """
     _constructor = ggplot2_env['stat_unique']
 stat_unique = StatUnique.new
 
-class StatVline(Stat):
-    """ Vertival line. """
-    _constructor = ggplot2_env['stat_vline']
-stat_vline = StatVline.new
-
 class Coord(GBaseObject):
     """ Coordinates """
     pass
@@ -373,13 +387,17 @@ class GeomDensity(Geom):
 geom_density = GeomDensity.new
 
 class GeomDensity2D(Geom):
-    _constructor = ggplot2_env['geom_density2d']
+    try:
+       _constructor = ggplot2_env['geom_density_2d']
+    except:
+       _constructor = ggplot2_env['geom_density2d']
 geom_density2d = GeomDensity2D.new
+geom_density_2d = GeomDensity2D.new
 
 class GeomDotplot(Geom):
-    _constructor = ggplot2_env['geom_dotplot']
+   _constructor = ggplot2_env['geom_dotplot']
 geom_dotplot = GeomDotplot.new
-
+   
 class GeomErrorBar(Geom):
     _constructor = ggplot2_env['geom_errorbar']
 geom_errorbar = GeomErrorBar.new
@@ -460,6 +478,11 @@ class GeomSmooth(Geom):
     _constructor = ggplot2_env['geom_smooth']
 geom_smooth = GeomSmooth.new
 
+class GeomSpoke(Geom):
+    """ Convert angle and radius to xend and yend """
+    _constructor = ggplot2_env['geom_spoke']
+geom_spoke = GeomSpoke.new
+
 class GeomStep(Geom):
     _constructor = ggplot2_env['geom_step']
 geom_step = GeomStep.new
@@ -578,36 +601,57 @@ scale_x_sqrt = ScaleXSqrt.new
 class ScaleYSqrt(ScaleY):
     _constructor = ggplot2_env['scale_y_sqrt']
 scale_y_sqrt = ScaleYSqrt.new
+
 class ScaleColourBrewer(ScaleColour):
     _constructor = ggplot2_env['scale_colour_brewer']
 scale_colour_brewer = ScaleColourBrewer.new
+scale_color_brewer = scale_colour_brewer
+
 class ScaleColourContinuous(ScaleColour):
     _constructor = ggplot2_env['scale_colour_continuous']
 scale_colour_continuous = ScaleColourContinuous.new
+scale_color_continuous = scale_colour_continuous
+
 class ScaleColourDiscrete(ScaleColour):
     _constructor = ggplot2_env['scale_colour_discrete']
 scale_colour_discrete = ScaleColourDiscrete.new
+scale_color_discrete = scale_colour_discrete
+
 class ScaleColourGradient(ScaleColour):
     _constructor = ggplot2_env['scale_colour_gradient']
 scale_colour_gradient = ScaleColourGradient.new
+scale_color_gradient = scale_colour_gradient
+
 class ScaleColourGradient2(ScaleColour):
     _constructor = ggplot2_env['scale_colour_gradient2']
 scale_colour_gradient2 = ScaleColourGradient2.new
+scale_color_gradient2 = scale_colour_gradient2
+
 class ScaleColourGradientN(ScaleColour):
     _constructor = ggplot2_env['scale_colour_gradientn']
 scale_colour_gradientn = ScaleColourGradientN.new
+scale_color_gradientn = scale_colour_gradientn
+
 class ScaleColourGrey(ScaleColour):
     _constructor = ggplot2_env['scale_colour_grey']
 scale_colour_grey = ScaleColourGrey.new
+scale_color_grey = scale_colour_grey
+
 class ScaleColourHue(ScaleColour):
     _constructor = ggplot2_env['scale_colour_hue']
 scale_colour_hue = ScaleColourHue.new
+scale_color_hue = scale_colour_hue
+
 class ScaleColourIdentity(ScaleColour):
     _constructor = ggplot2_env['scale_colour_identity']
 scale_colour_identity = ScaleColourIdentity.new
+scale_color_identity = scale_colour_identity
+
 class ScaleColourManual(ScaleColour):
     _constructor = ggplot2_env['scale_colour_manual']
 scale_colour_manual = ScaleColourManual.new
+scale_color_manual = scale_colour_manual
+
 class ScaleFillBrewer(ScaleFill):
     _constructor = ggplot2_env['scale_fill_brewer']
 scale_fill_brewer = ScaleFillBrewer.new
@@ -638,6 +682,12 @@ scale_fill_identity = ScaleFillIdentity.new
 class ScaleFillManual(ScaleFill):
     _constructor = ggplot2_env['scale_fill_manual']
 scale_fill_manual = ScaleFillManual.new
+class ScaleLinetypeContinuous(ScaleLinetype):
+    _constructor = ggplot2_env['scale_linetype_continuous']
+scale_linetype_continuous = ScaleLinetypeContinuous.new
+class ScaleLinetypeDiscrete(ScaleLinetype):
+    _constructor = ggplot2_env['scale_linetype_discrete']
+scale_linetype_discrete = ScaleLinetypeDiscrete.new
 class ScaleLinetypeManual(ScaleLinetype):
     _constructor = ggplot2_env['scale_linetype_manual']
 scale_linetype_manual = ScaleLinetypeManual.new
@@ -709,15 +759,6 @@ class ElementBlank(Theme):
 
 element_blank = ElementBlank.new
 
-class ThemeBlank(Theme):
-    _constructor = ggplot2.theme_blank
-    @classmethod
-    def new(cls):
-        res = cls(cls._constructor())
-        return res
-
-theme_blank = ThemeBlank.new
-
 theme_get = ggplot2.theme_get
 
 class ThemeGrey(Theme):
@@ -739,25 +780,25 @@ class ThemeClassic(Theme):
 
 theme_classic = ThemeClassic.new
 
-class ThemeRect(Theme):
-    _constructor = ggplot2.theme_rect
+class ThemeDark(Theme):
+    _constructor = ggplot2.theme_dark
     @classmethod
-    def new(cls, fill = robjects.NA_Logical, colour = "black", 
-            size = 0.5, linetype = 1):
-       res = cls(cls._constructor(fill = fill, colour = colour, 
-                                  size = size, linetype = linetype))
+    def new(cls, base_size = 12, base_family = ""):
+       res = cls(cls._constructor(base_size = base_size,
+                                  base_family = base_family))
        return res
-theme_rect = ThemeRect.new
 
-class ThemeSegment(Theme):
-    _constructor = ggplot2.theme_rect
+theme_dark = ThemeDark.new
+
+class ThemeLight(Theme):
+    _constructor = ggplot2.theme_light
     @classmethod
-    def new(cls, colour = 'black', size = 0.5, linetype = 1):
-       res = cls(cls._constructor(colour = colour, size = size,
-                                  linetype = linetype))
+    def new(cls, base_size = 12, base_family = ""):
+       res = cls(cls._constructor(base_size = base_size,
+                                  base_family = base_family))
        return res
-theme_segment = ThemeSegment.new
 
+theme_light = ThemeLight.new
 
 class ThemeBW(Theme):
     _constructor = ggplot2.theme_bw
@@ -775,15 +816,37 @@ class ThemeGray(Theme):
        res = cls(cls._constructor(base_size = base_size))
        return res
 theme_gray = ThemeGray.new
+theme_grey = theme_gray
 
-class ThemeLine(Theme):
-    _constructor = ggplot2.theme_line
+class ThemeMinimal(Theme):
+    _constructor = ggplot2.theme_minimal
     @classmethod
-    def new(cls, colour = 'black', size = 0.5, linetype = 1):
-       res = cls(cls._constructor(colour = colour, size = size,
-                                  linetype = linetype))
+    def new(cls, base_size = 12, base_family = ""):
+       res = cls(cls._constructor(base_size = base_size,
+                                  base_family = base_family))
        return res
-theme_line = ThemeLine.new
+
+theme_minimal = ThemeMinimal.new
+
+class ThemeLinedraw(Theme):
+    _constructor = ggplot2.theme_linedraw
+    @classmethod
+    def new(cls, base_size=12, base_family=""):
+       res = cls(cls._constructor(base_size=base_size,
+                                  base_family=base_family))
+       return res
+theme_linedraw = ThemeLinedraw.new
+
+class ThemeVoid(Theme):
+    _constructor = ggplot2.theme_void
+    @classmethod
+    def new(cls, base_size = 12, base_family = ""):
+       res = cls(cls._constructor(base_size = base_size,
+                                  base_family = base_family))
+       return res
+
+theme_void = ThemeVoid.new
+
 
 #theme_render
 theme_set = ggplot2.theme_set
@@ -794,8 +857,6 @@ gplot = ggplot2.qplot
 
 map_data = ggplot2.map_data
 
-opts = ggplot2_env['opts']
-
 theme = ggplot2_env['theme']
 
 ggtitle = ggplot2.ggtitle
