@@ -20,12 +20,11 @@ class RSlots(object):
     
     def __init__(self, robj):
         self._robj = weakref.proxy(robj)
-
         
     def __getitem__(self, key):
         value = self._robj.do_slot(key)
         return conversion.ri2ro(value)
-        
+
     def __setitem__(self, key, value):
         rpy2_value = conversion.py2ri(value)
         self._robj.do_slot_assign(key, rpy2_value)
@@ -37,14 +36,16 @@ class RSlots(object):
         for k in self._robj.list_attrs():
             yield k
 
+    __iter__=keys
+    
     def items(self):
         for k in self._robj.list_attrs():
-            v = self[key]
+            v = self[k]
             yield (k, v)
 
     def values(self):
         for k in self._robj.list_attrs():
-            v = self[key]
+            v = self[k]
             yield v
 
 
@@ -53,7 +54,7 @@ def _reduce_robjectmixin(rdumps, rtypeof,
                          rpy2type):
     rinterface_level=rinterface_factory(rdumps, rtypeof)
     return rpy2type(rinterface_level)
-
+        
 class RObjectMixin(object):
     """ Class to provide methods common to all RObject instances """
     __rname__ = None
@@ -81,6 +82,16 @@ class RObjectMixin(object):
             self.__slots = RSlots(self)
         return self.__slots
 
+    def __repr__(self):
+        try:
+            rclasses = ('R object with classes: {} mapped to:'
+                        .format(tuple(self.rclass)))
+        except:
+            rclasses = 'Unable to fetch R classes.' + os.linesep
+        res = os.linesep.join((rclasses,
+                               super(RObjectMixin, self).__repr__()))
+        return res
+    
     def __str__(self):
         if sys.platform == 'win32':
             tmpf = tempfile.NamedTemporaryFile(mode="w+", delete=False)
@@ -130,11 +141,28 @@ class RObjectMixin(object):
             else:
                 raise rre
     def _rclass_set(self, value):
-        res = self.__rclass_set(self, value)
+        if isinstance(value, str):
+            value = (value, )
+        new_cls = rpy2.rinterface.StrSexpVector(value)
+        res = self.__rclass_set(self, new_cls)
         self.__sexp__ = res.__sexp__
             
     rclass = property(_rclass_get, _rclass_set, None,
-                      "R class for the object, stored as an R string vector.")
+                      """
+R class for the object, stored as an R string vector.
+
+When setting the rclass, the new value will be:
+- wrapped in a Python tuple if a string (the R class
+  is a vector of strings, and this is made for convenience)
+- wrapped in a StrSexpVector
+Note that when setting the class R may make a copy of
+the whole object (R is mostly a functional language).
+If this must be avoided, and if the number of parent
+classes before and after the change are compatible,
+the class name can be changed in-place by replacing "
+vector elements.
+                      """)
+
 
     # Python 3-only
     if sys.version_info[0] == 2:
@@ -165,7 +193,7 @@ class RObjectMixin(object):
             l[0] = _reduce_robjectmixin
             return tuple(l)
 
-        
+    
 def repr_robject(o, linesep=os.linesep):
     s = rpy2.rinterface.baseenv.get("deparse")(o)
     s = str.join(linesep, s)
